==> botcommander-0.1.tar.gz: botcommander-0.1/include/defines.h <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/***************************************************************************
 *            defines.h
 *
 *  Thu Aug 26 23:19:26 2004
 *  Copyright  2004  Gergely POLONKAI
 *  polesz@techinfo.hu
 ****************************************************************************/

#ifndef _BC_DEFINES_H
# define _BC_DEFINES_H

/* Function type of command callbacks. */
# define BC_COMMAND(x) gboolean x (int paramnum, gchar **param)
/* In typedefs.h there is a struct which is for the command list.
 * To make life easyer, you only have to change the function's type here (and
 * in the previous line), so you don't have to edit multiple lines.
 */
# define BC_COMMAND_DEF(x) gboolean (* x )(int, gchar **)

/* Command type constants */
# define CT_INTERNAL 0
# define CT_MODULE   1
# define CT_SCRIPT   2

#endif /* _BC_DEFINES_H */

==> botcommander-0.2.tar.gz: botcommander-0.2/include/defines.h <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/***************************************************************************
 *            defines.h
 *
 *  Thu Aug 26 23:19:26 2004
 *  Copyright  2004  Gergely POLONKAI
 *  polesz@techinfo.hu
 ****************************************************************************/

#ifndef _BC_DEFINES_H
# define _BC_DEFINES_H

/* Function type of command callbacks. */
# define BC_COMMAND(x) gboolean x (int paramnum, gchar **param)
/* In typedefs.h there is a struct which is for the command list.
 * To make life easyer, you only have to change the function's type here (and
 * in the previous line), so you don't have to edit multiple lines.
 */
# define BC_COMMAND_DEF(x) gboolean (* x )(int, gchar **)

/* Command type constants */
# define CT_INTERNAL 0
# define CT_MODULE   1
# define CT_SCRIPT   2

/* Configure backend types. Change the default with the configure option
 * --with-config-backend
 */
# define CB_GCONF2 0
# define CB_XML    1
# define CB_SAMBA  2

#endif /* _BC_DEFINES_H */
